# pulp_file_client

PulpFileClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 1.6.1
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_file_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_file_client-1.6.1.gem
```

(for development, run `gem install --dev ./pulp_file_client-1.6.1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_file_client', '~> 1.6.1'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_file_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_file_client'

# Setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpFileClient::ContentFilesApi.new
relative_path = 'relative_path_example' # String | Path where the artifact is located relative to distributions base_path
opts = {
  artifact: 'artifact_example', # String | Artifact file representing the physical content
  file: File.new('/path/to/file'), # File | An uploaded file that may be turned into the artifact of the content unit.
  repository: 'repository_example' # String | A URI of a repository the new content unit should be associated with.
}

begin
  #Create a file content
  result = api_instance.create(relative_path, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling ContentFilesApi->create: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpFileClient::ContentFilesApi* | [**create**](docs/ContentFilesApi.md#create) | **POST** /pulp/api/v3/content/file/files/ | Create a file content
*PulpFileClient::ContentFilesApi* | [**list**](docs/ContentFilesApi.md#list) | **GET** /pulp/api/v3/content/file/files/ | List file contents
*PulpFileClient::ContentFilesApi* | [**read**](docs/ContentFilesApi.md#read) | **GET** {file_file_content_href} | Inspect a file content
*PulpFileClient::DistributionsFileApi* | [**create**](docs/DistributionsFileApi.md#create) | **POST** /pulp/api/v3/distributions/file/file/ | Create a file distribution
*PulpFileClient::DistributionsFileApi* | [**delete**](docs/DistributionsFileApi.md#delete) | **DELETE** {file_file_distribution_href} | Delete a file distribution
*PulpFileClient::DistributionsFileApi* | [**list**](docs/DistributionsFileApi.md#list) | **GET** /pulp/api/v3/distributions/file/file/ | List file distributions
*PulpFileClient::DistributionsFileApi* | [**partial_update**](docs/DistributionsFileApi.md#partial_update) | **PATCH** {file_file_distribution_href} | Update a file distribution
*PulpFileClient::DistributionsFileApi* | [**read**](docs/DistributionsFileApi.md#read) | **GET** {file_file_distribution_href} | Inspect a file distribution
*PulpFileClient::DistributionsFileApi* | [**update**](docs/DistributionsFileApi.md#update) | **PUT** {file_file_distribution_href} | Update a file distribution
*PulpFileClient::ExportersFileExportsApi* | [**create**](docs/ExportersFileExportsApi.md#create) | **POST** {file_file_filesystem_exporter_href}exports/ | Create an export
*PulpFileClient::ExportersFileExportsApi* | [**delete**](docs/ExportersFileExportsApi.md#delete) | **DELETE** {file_filesystem_export_href} | Delete an export
*PulpFileClient::ExportersFileExportsApi* | [**list**](docs/ExportersFileExportsApi.md#list) | **GET** {file_file_filesystem_exporter_href}exports/ | List exports
*PulpFileClient::ExportersFileExportsApi* | [**read**](docs/ExportersFileExportsApi.md#read) | **GET** {file_filesystem_export_href} | Inspect an export
*PulpFileClient::ExportersFilesystemApi* | [**create**](docs/ExportersFilesystemApi.md#create) | **POST** /pulp/api/v3/exporters/file/filesystem/ | Create a file filesystem exporter
*PulpFileClient::ExportersFilesystemApi* | [**delete**](docs/ExportersFilesystemApi.md#delete) | **DELETE** {file_file_filesystem_exporter_href} | Delete a file filesystem exporter
*PulpFileClient::ExportersFilesystemApi* | [**list**](docs/ExportersFilesystemApi.md#list) | **GET** /pulp/api/v3/exporters/file/filesystem/ | List file filesystem exporters
*PulpFileClient::ExportersFilesystemApi* | [**partial_update**](docs/ExportersFilesystemApi.md#partial_update) | **PATCH** {file_file_filesystem_exporter_href} | Update a file filesystem exporter
*PulpFileClient::ExportersFilesystemApi* | [**read**](docs/ExportersFilesystemApi.md#read) | **GET** {file_file_filesystem_exporter_href} | Inspect a file filesystem exporter
*PulpFileClient::ExportersFilesystemApi* | [**update**](docs/ExportersFilesystemApi.md#update) | **PUT** {file_file_filesystem_exporter_href} | Update a file filesystem exporter
*PulpFileClient::PublicationsFileApi* | [**create**](docs/PublicationsFileApi.md#create) | **POST** /pulp/api/v3/publications/file/file/ | Create a file publication
*PulpFileClient::PublicationsFileApi* | [**delete**](docs/PublicationsFileApi.md#delete) | **DELETE** {file_file_publication_href} | Delete a file publication
*PulpFileClient::PublicationsFileApi* | [**list**](docs/PublicationsFileApi.md#list) | **GET** /pulp/api/v3/publications/file/file/ | List file publications
*PulpFileClient::PublicationsFileApi* | [**read**](docs/PublicationsFileApi.md#read) | **GET** {file_file_publication_href} | Inspect a file publication
*PulpFileClient::RemotesFileApi* | [**create**](docs/RemotesFileApi.md#create) | **POST** /pulp/api/v3/remotes/file/file/ | Create a file remote
*PulpFileClient::RemotesFileApi* | [**delete**](docs/RemotesFileApi.md#delete) | **DELETE** {file_file_remote_href} | Delete a file remote
*PulpFileClient::RemotesFileApi* | [**list**](docs/RemotesFileApi.md#list) | **GET** /pulp/api/v3/remotes/file/file/ | List file remotes
*PulpFileClient::RemotesFileApi* | [**partial_update**](docs/RemotesFileApi.md#partial_update) | **PATCH** {file_file_remote_href} | Update a file remote
*PulpFileClient::RemotesFileApi* | [**read**](docs/RemotesFileApi.md#read) | **GET** {file_file_remote_href} | Inspect a file remote
*PulpFileClient::RemotesFileApi* | [**update**](docs/RemotesFileApi.md#update) | **PUT** {file_file_remote_href} | Update a file remote
*PulpFileClient::RepositoriesFileApi* | [**create**](docs/RepositoriesFileApi.md#create) | **POST** /pulp/api/v3/repositories/file/file/ | Create a file repository
*PulpFileClient::RepositoriesFileApi* | [**delete**](docs/RepositoriesFileApi.md#delete) | **DELETE** {file_file_repository_href} | Delete a file repository
*PulpFileClient::RepositoriesFileApi* | [**list**](docs/RepositoriesFileApi.md#list) | **GET** /pulp/api/v3/repositories/file/file/ | List file repositorys
*PulpFileClient::RepositoriesFileApi* | [**modify**](docs/RepositoriesFileApi.md#modify) | **POST** {file_file_repository_href}modify/ | Modify Repository Content
*PulpFileClient::RepositoriesFileApi* | [**partial_update**](docs/RepositoriesFileApi.md#partial_update) | **PATCH** {file_file_repository_href} | Update a file repository
*PulpFileClient::RepositoriesFileApi* | [**read**](docs/RepositoriesFileApi.md#read) | **GET** {file_file_repository_href} | Inspect a file repository
*PulpFileClient::RepositoriesFileApi* | [**sync**](docs/RepositoriesFileApi.md#sync) | **POST** {file_file_repository_href}sync/ | 
*PulpFileClient::RepositoriesFileApi* | [**update**](docs/RepositoriesFileApi.md#update) | **PUT** {file_file_repository_href} | Update a file repository
*PulpFileClient::RepositoriesFileVersionsApi* | [**delete**](docs/RepositoriesFileVersionsApi.md#delete) | **DELETE** {file_file_repository_version_href} | Delete a repository version
*PulpFileClient::RepositoriesFileVersionsApi* | [**list**](docs/RepositoriesFileVersionsApi.md#list) | **GET** {file_file_repository_href}versions/ | List repository versions
*PulpFileClient::RepositoriesFileVersionsApi* | [**read**](docs/RepositoriesFileVersionsApi.md#read) | **GET** {file_file_repository_version_href} | Inspect a repository version
*PulpFileClient::RepositoriesFileVersionsApi* | [**repair**](docs/RepositoriesFileVersionsApi.md#repair) | **POST** {file_file_repository_version_href}repair/ | 


## Documentation for Models

 - [PulpFileClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpFileClient::ContentSummary](docs/ContentSummary.md)
 - [PulpFileClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpFileClient::ExportResponse](docs/ExportResponse.md)
 - [PulpFileClient::FileFileContent](docs/FileFileContent.md)
 - [PulpFileClient::FileFileContentResponse](docs/FileFileContentResponse.md)
 - [PulpFileClient::FileFileDistribution](docs/FileFileDistribution.md)
 - [PulpFileClient::FileFileDistributionResponse](docs/FileFileDistributionResponse.md)
 - [PulpFileClient::FileFileFilesystemExporter](docs/FileFileFilesystemExporter.md)
 - [PulpFileClient::FileFileFilesystemExporterResponse](docs/FileFileFilesystemExporterResponse.md)
 - [PulpFileClient::FileFilePublication](docs/FileFilePublication.md)
 - [PulpFileClient::FileFilePublicationResponse](docs/FileFilePublicationResponse.md)
 - [PulpFileClient::FileFileRemote](docs/FileFileRemote.md)
 - [PulpFileClient::FileFileRemoteResponse](docs/FileFileRemoteResponse.md)
 - [PulpFileClient::FileFileRepository](docs/FileFileRepository.md)
 - [PulpFileClient::FileFileRepositoryResponse](docs/FileFileRepositoryResponse.md)
 - [PulpFileClient::PaginatedExportResponseList](docs/PaginatedExportResponseList.md)
 - [PulpFileClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpFileClient::PaginatedfileFileContentResponseList](docs/PaginatedfileFileContentResponseList.md)
 - [PulpFileClient::PaginatedfileFileDistributionResponseList](docs/PaginatedfileFileDistributionResponseList.md)
 - [PulpFileClient::PaginatedfileFileFilesystemExporterResponseList](docs/PaginatedfileFileFilesystemExporterResponseList.md)
 - [PulpFileClient::PaginatedfileFilePublicationResponseList](docs/PaginatedfileFilePublicationResponseList.md)
 - [PulpFileClient::PaginatedfileFileRemoteResponseList](docs/PaginatedfileFileRemoteResponseList.md)
 - [PulpFileClient::PaginatedfileFileRepositoryResponseList](docs/PaginatedfileFileRepositoryResponseList.md)
 - [PulpFileClient::PatchedfileFileDistribution](docs/PatchedfileFileDistribution.md)
 - [PulpFileClient::PatchedfileFileFilesystemExporter](docs/PatchedfileFileFilesystemExporter.md)
 - [PulpFileClient::PatchedfileFileRemote](docs/PatchedfileFileRemote.md)
 - [PulpFileClient::PatchedfileFileRepository](docs/PatchedfileFileRepository.md)
 - [PulpFileClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpFileClient::PublicationExport](docs/PublicationExport.md)
 - [PulpFileClient::RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [PulpFileClient::RepositorySyncURL](docs/RepositorySyncURL.md)
 - [PulpFileClient::RepositoryVersion](docs/RepositoryVersion.md)
 - [PulpFileClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

