# PulpFileClient::ExportersFileExportsApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ExportersFileExportsApi.md#create) | **POST** {file_file_filesystem_exporter_href}exports/ | Create an export
[**delete**](ExportersFileExportsApi.md#delete) | **DELETE** {file_filesystem_export_href} | Delete an export
[**list**](ExportersFileExportsApi.md#list) | **GET** {file_file_filesystem_exporter_href}exports/ | List exports
[**read**](ExportersFileExportsApi.md#read) | **GET** {file_filesystem_export_href} | Inspect an export



## create

> AsyncOperationResponse create(file_file_filesystem_exporter_href, publication_export)

Create an export

Trigger an asynchronous task to export a file publication.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::ExportersFileExportsApi.new
file_file_filesystem_exporter_href = 'file_file_filesystem_exporter_href_example' # String | 
publication_export = PulpFileClient::PublicationExport.new # PublicationExport | 

begin
  #Create an export
  result = api_instance.create(file_file_filesystem_exporter_href, publication_export)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling ExportersFileExportsApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_filesystem_exporter_href** | **String**|  | 
 **publication_export** | [**PublicationExport**](PublicationExport.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(file_filesystem_export_href)

Delete an export

FilesystemExports provide a history of previous exports.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::ExportersFileExportsApi.new
file_filesystem_export_href = 'file_filesystem_export_href_example' # String | 

begin
  #Delete an export
  api_instance.delete(file_filesystem_export_href)
rescue PulpFileClient::ApiError => e
  puts "Exception when calling ExportersFileExportsApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_filesystem_export_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginatedExportResponseList list(file_file_filesystem_exporter_href, opts)

List exports

FilesystemExports provide a history of previous exports.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::ExportersFileExportsApi.new
file_file_filesystem_exporter_href = 'file_file_filesystem_exporter_href_example' # String | 
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List exports
  result = api_instance.list(file_file_filesystem_exporter_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling ExportersFileExportsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_filesystem_exporter_href** | **String**|  | 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedExportResponseList**](PaginatedExportResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> ExportResponse read(file_filesystem_export_href, opts)

Inspect an export

FilesystemExports provide a history of previous exports.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::ExportersFileExportsApi.new
file_filesystem_export_href = 'file_filesystem_export_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an export
  result = api_instance.read(file_filesystem_export_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling ExportersFileExportsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_filesystem_export_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**ExportResponse**](ExportResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

