# PulpFileClient::PublicationsFileApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](PublicationsFileApi.md#create) | **POST** /pulp/api/v3/publications/file/file/ | Create a file publication
[**delete**](PublicationsFileApi.md#delete) | **DELETE** {file_file_publication_href} | Delete a file publication
[**list**](PublicationsFileApi.md#list) | **GET** /pulp/api/v3/publications/file/file/ | List file publications
[**read**](PublicationsFileApi.md#read) | **GET** {file_file_publication_href} | Inspect a file publication



## create

> AsyncOperationResponse create(file_file_publication)

Create a file publication

Trigger an asynchronous task to publish file content.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::PublicationsFileApi.new
file_file_publication = PulpFileClient::FileFilePublication.new # FileFilePublication | 

begin
  #Create a file publication
  result = api_instance.create(file_file_publication)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling PublicationsFileApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_publication** | [**FileFilePublication**](FileFilePublication.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(file_file_publication_href)

Delete a file publication

 A FilePublication contains metadata about all the File Content in a particular File Repository Version. Once a FilePublication has been created, it can be hosted using the File Distribution API.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::PublicationsFileApi.new
file_file_publication_href = 'file_file_publication_href_example' # String | 

begin
  #Delete a file publication
  api_instance.delete(file_file_publication_href)
rescue PulpFileClient::ApiError => e
  puts "Exception when calling PublicationsFileApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_publication_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginatedfileFilePublicationResponseList list(opts)

List file publications

 A FilePublication contains metadata about all the File Content in a particular File Repository Version. Once a FilePublication has been created, it can be hosted using the File Distribution API.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::PublicationsFileApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_created: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | ISO 8601 formatted dates are supported
  pulp_created__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than value
  pulp_created__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than or equal to value
  pulp_created__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than value
  pulp_created__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than or equal to value
  pulp_created__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_created is between two comma separated values
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List file publications
  result = api_instance.list(opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling PublicationsFileApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_created** | **DateTime**| ISO 8601 formatted dates are supported | [optional] 
 **pulp_created__gt** | **DateTime**| Filter results where pulp_created is greater than value | [optional] 
 **pulp_created__gte** | **DateTime**| Filter results where pulp_created is greater than or equal to value | [optional] 
 **pulp_created__lt** | **DateTime**| Filter results where pulp_created is less than value | [optional] 
 **pulp_created__lte** | **DateTime**| Filter results where pulp_created is less than or equal to value | [optional] 
 **pulp_created__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_created is between two comma separated values | [optional] 
 **repository_version** | [**String**](.md)| Repository Version referenced by HREF | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedfileFilePublicationResponseList**](PaginatedfileFilePublicationResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> FileFilePublicationResponse read(file_file_publication_href, opts)

Inspect a file publication

 A FilePublication contains metadata about all the File Content in a particular File Repository Version. Once a FilePublication has been created, it can be hosted using the File Distribution API.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::PublicationsFileApi.new
file_file_publication_href = 'file_file_publication_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a file publication
  result = api_instance.read(file_file_publication_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling PublicationsFileApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_publication_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**FileFilePublicationResponse**](FileFilePublicationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

